pub enum DispatchError {
NotReady,
Shutdown,
}Expand description
Error returned when work can no longer be posted to the main thread.
Variants
NotReady
The shell has not completed initialization yet.
Shutdown
The application is shutting down and no longer accepts callbacks.