pub enum PluginError {
Unsupported,
InvalidDescriptor,
Busy,
NoFrame,
Shutdown,
}Expand description
Errors returned while registering a Rust-shell plugin.
Variants
Unsupported
The plugin requires an SDK capability not provided by this shell build.
InvalidDescriptor
A texture descriptor has zero or unsupported dimensions or format.
Busy
Every ring slot is currently reserved, ready, or used by Flutter.
NoFrame
The reserved frame has not recorded any commands yet.
Shutdown
The texture or shell is shutting down.