pub struct MainThreadDispatcher { /* private fields */ }Expand description
Worker-safe handle for posting short operations to Flutter’s main thread.
Dispatch is always asynchronous, including when called from the main thread. This prevents a callback from unexpectedly re-entering Dart or mutable platform state in the middle of an FFI call.
Implementations
Sourceimpl MainThreadDispatcher
impl MainThreadDispatcher
Sourcepub fn dispatch(
&self,
task: impl FnOnce() + Send + 'static,
) -> Result<(), DispatchError>
pub fn dispatch( &self, task: impl FnOnce() + Send + 'static, ) -> Result<(), DispatchError>
Posts task for a later turn of the main event loop.
Sourcepub fn is_main_thread(&self) -> bool
pub fn is_main_thread(&self) -> bool
Whether the caller is currently running on the owning main thread.